# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2payoutsRecipientInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'middle_initial': 'str',
        'last_name': 'str',
        'address1': 'str',
        'locality': 'str',
        'administrative_area': 'str',
        'country': 'str',
        'postal_code': 'str',
        'phone_number': 'str',
        'date_of_birth': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'middle_initial': 'middleInitial',
        'last_name': 'lastName',
        'address1': 'address1',
        'locality': 'locality',
        'administrative_area': 'administrativeArea',
        'country': 'country',
        'postal_code': 'postalCode',
        'phone_number': 'phoneNumber',
        'date_of_birth': 'dateOfBirth'
    }

    def __init__(self, first_name=None, middle_initial=None, last_name=None, address1=None, locality=None, administrative_area=None, country=None, postal_code=None, phone_number=None, date_of_birth=None):
        """
        Ptsv2payoutsRecipientInformation - a model defined in Swagger
        """

        self._first_name = None
        self._middle_initial = None
        self._last_name = None
        self._address1 = None
        self._locality = None
        self._administrative_area = None
        self._country = None
        self._postal_code = None
        self._phone_number = None
        self._date_of_birth = None

        if first_name is not None:
          self.first_name = first_name
        if middle_initial is not None:
          self.middle_initial = middle_initial
        if last_name is not None:
          self.last_name = last_name
        if address1 is not None:
          self.address1 = address1
        if locality is not None:
          self.locality = locality
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if country is not None:
          self.country = country
        if postal_code is not None:
          self.postal_code = postal_code
        if phone_number is not None:
          self.phone_number = phone_number
        if date_of_birth is not None:
          self.date_of_birth = date_of_birth

    @property
    def first_name(self):
        """
        Gets the first_name of this Ptsv2payoutsRecipientInformation.
        First name of recipient. characters. * CTV (14) * Paymentech (30) 

        :return: The first_name of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Ptsv2payoutsRecipientInformation.
        First name of recipient. characters. * CTV (14) * Paymentech (30) 

        :param first_name: The first_name of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if first_name is not None and len(first_name) > 35:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `35`")

        self._first_name = first_name

    @property
    def middle_initial(self):
        """
        Gets the middle_initial of this Ptsv2payoutsRecipientInformation.
        Middle Initial of recipient. Required only for FDCCompass. 

        :return: The middle_initial of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._middle_initial

    @middle_initial.setter
    def middle_initial(self, middle_initial):
        """
        Sets the middle_initial of this Ptsv2payoutsRecipientInformation.
        Middle Initial of recipient. Required only for FDCCompass. 

        :param middle_initial: The middle_initial of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if middle_initial is not None and len(middle_initial) > 1:
            raise ValueError("Invalid value for `middle_initial`, length must be less than or equal to `1`")

        self._middle_initial = middle_initial

    @property
    def last_name(self):
        """
        Gets the last_name of this Ptsv2payoutsRecipientInformation.
        Last name of recipient. characters. * CTV (14) * Paymentech (30) 

        :return: The last_name of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Ptsv2payoutsRecipientInformation.
        Last name of recipient. characters. * CTV (14) * Paymentech (30) 

        :param last_name: The last_name of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if last_name is not None and len(last_name) > 35:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `35`")

        self._last_name = last_name

    @property
    def address1(self):
        """
        Gets the address1 of this Ptsv2payoutsRecipientInformation.
        Recipient address information. Required only for FDCCompass.

        :return: The address1 of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this Ptsv2payoutsRecipientInformation.
        Recipient address information. Required only for FDCCompass.

        :param address1: The address1 of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if address1 is not None and len(address1) > 50:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `50`")

        self._address1 = address1

    @property
    def locality(self):
        """
        Gets the locality of this Ptsv2payoutsRecipientInformation.
        Recipient city. Required only for FDCCompass.

        :return: The locality of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Ptsv2payoutsRecipientInformation.
        Recipient city. Required only for FDCCompass.

        :param locality: The locality of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if locality is not None and len(locality) > 25:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `25`")

        self._locality = locality

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Ptsv2payoutsRecipientInformation.
        Recipient State. Required only for FDCCompass.

        :return: The administrative_area of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Ptsv2payoutsRecipientInformation.
        Recipient State. Required only for FDCCompass.

        :param administrative_area: The administrative_area of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if administrative_area is not None and len(administrative_area) > 3:
            raise ValueError("Invalid value for `administrative_area`, length must be less than or equal to `3`")

        self._administrative_area = administrative_area

    @property
    def country(self):
        """
        Gets the country of this Ptsv2payoutsRecipientInformation.
        Recipient country code. Required only for FDCCompass.

        :return: The country of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Ptsv2payoutsRecipientInformation.
        Recipient country code. Required only for FDCCompass.

        :param country: The country of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Ptsv2payoutsRecipientInformation.
        Recipient postal code. Required only for FDCCompass.

        :return: The postal_code of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Ptsv2payoutsRecipientInformation.
        Recipient postal code. Required only for FDCCompass.

        :param postal_code: The postal_code of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 10:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `10`")

        self._postal_code = postal_code

    @property
    def phone_number(self):
        """
        Gets the phone_number of this Ptsv2payoutsRecipientInformation.
        Recipient phone number. Required only for FDCCompass.

        :return: The phone_number of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this Ptsv2payoutsRecipientInformation.
        Recipient phone number. Required only for FDCCompass.

        :param phone_number: The phone_number of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 20:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `20`")

        self._phone_number = phone_number

    @property
    def date_of_birth(self):
        """
        Gets the date_of_birth of this Ptsv2payoutsRecipientInformation.
        Recipient date of birth in YYYYMMDD format. Required only for FDCCompass.

        :return: The date_of_birth of this Ptsv2payoutsRecipientInformation.
        :rtype: str
        """
        return self._date_of_birth

    @date_of_birth.setter
    def date_of_birth(self, date_of_birth):
        """
        Sets the date_of_birth of this Ptsv2payoutsRecipientInformation.
        Recipient date of birth in YYYYMMDD format. Required only for FDCCompass.

        :param date_of_birth: The date_of_birth of this Ptsv2payoutsRecipientInformation.
        :type: str
        """
        if date_of_birth is not None and len(date_of_birth) > 8:
            raise ValueError("Invalid value for `date_of_birth`, length must be less than or equal to `8`")
        if date_of_birth is not None and len(date_of_birth) < 8:
            raise ValueError("Invalid value for `date_of_birth`, length must be greater than or equal to `8`")

        self._date_of_birth = date_of_birth

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2payoutsRecipientInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsPaymentInformationPaymentInstrument(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str'
    }

    attribute_map = {
        'id': 'id'
    }

    def __init__(self, id=None):
        """
        Ptsv2paymentsPaymentInformationPaymentInstrument - a model defined in Swagger
        """

        self._id = None

        if id is not None:
          self.id = id

    @property
    def id(self):
        """
        Gets the id of this Ptsv2paymentsPaymentInformationPaymentInstrument.
        Unique identifier for the Payment Instrument token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional. 

        :return: The id of this Ptsv2paymentsPaymentInformationPaymentInstrument.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Ptsv2paymentsPaymentInformationPaymentInstrument.
        Unique identifier for the Payment Instrument token used in the transaction. When you include this value in your request, many of the fields that are normally required for an authorization or credit become optional. 

        :param id: The id of this Ptsv2paymentsPaymentInformationPaymentInstrument.
        :type: str
        """
        if id is not None and len(id) > 32:
            raise ValueError("Invalid value for `id`, length must be less than or equal to `32`")
        if id is not None and len(id) < 1:
            raise ValueError("Invalid value for `id`, length must be greater than or equal to `1`")

        self._id = id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsPaymentInformationPaymentInstrument):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3NetFundingsGet200Response(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'start_time': 'datetime',
        'end_time': 'datetime',
        'net_funding_summaries': 'list[ReportingV3NetFundingsGet200ResponseNetFundingSummaries]',
        'total_purchases': 'list[ReportingV3NetFundingsGet200ResponseTotalPurchases]',
        'total_refunds': 'list[ReportingV3NetFundingsGet200ResponseTotalPurchases]',
        'total_fees': 'list[ReportingV3NetFundingsGet200ResponseTotalPurchases]',
        'total_chargebacks': 'list[ReportingV3NetFundingsGet200ResponseTotalPurchases]',
        'net_total': 'list[ReportingV3NetFundingsGet200ResponseTotalPurchases]'
    }

    attribute_map = {
        'start_time': 'startTime',
        'end_time': 'endTime',
        'net_funding_summaries': 'netFundingSummaries',
        'total_purchases': 'totalPurchases',
        'total_refunds': 'totalRefunds',
        'total_fees': 'totalFees',
        'total_chargebacks': 'totalChargebacks',
        'net_total': 'netTotal'
    }

    def __init__(self, start_time=None, end_time=None, net_funding_summaries=None, total_purchases=None, total_refunds=None, total_fees=None, total_chargebacks=None, net_total=None):
        """
        ReportingV3NetFundingsGet200Response - a model defined in Swagger
        """

        self._start_time = None
        self._end_time = None
        self._net_funding_summaries = None
        self._total_purchases = None
        self._total_refunds = None
        self._total_fees = None
        self._total_chargebacks = None
        self._net_total = None

        if start_time is not None:
          self.start_time = start_time
        if end_time is not None:
          self.end_time = end_time
        if net_funding_summaries is not None:
          self.net_funding_summaries = net_funding_summaries
        if total_purchases is not None:
          self.total_purchases = total_purchases
        if total_refunds is not None:
          self.total_refunds = total_refunds
        if total_fees is not None:
          self.total_fees = total_fees
        if total_chargebacks is not None:
          self.total_chargebacks = total_chargebacks
        if net_total is not None:
          self.net_total = net_total

    @property
    def start_time(self):
        """
        Gets the start_time of this ReportingV3NetFundingsGet200Response.
        Valid report Start Date in **ISO 8601 format**. Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)  **Example:** - yyyy-MM-dd'T'HH:mm:ss.SSSZZ 

        :return: The start_time of this ReportingV3NetFundingsGet200Response.
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """
        Sets the start_time of this ReportingV3NetFundingsGet200Response.
        Valid report Start Date in **ISO 8601 format**. Please refer the following link to know more about ISO 8601 format.[Rfc Date Format](https://xml2rfc.tools.ietf.org/public/rfc/html/rfc3339.html#anchor14)  **Example:** - yyyy-MM-dd'T'HH:mm:ss.SSSZZ 

        :param start_time: The start_time of this ReportingV3NetFundingsGet200Response.
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_time(self):
        """
        Gets the end_time of this ReportingV3NetFundingsGet200Response.
        Valid report End Date in **ISO 8601 format** **Example date format:** - yyyy-MM-dd'T'HH:mm:ss.SSSZZ 

        :return: The end_time of this ReportingV3NetFundingsGet200Response.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this ReportingV3NetFundingsGet200Response.
        Valid report End Date in **ISO 8601 format** **Example date format:** - yyyy-MM-dd'T'HH:mm:ss.SSSZZ 

        :param end_time: The end_time of this ReportingV3NetFundingsGet200Response.
        :type: datetime
        """

        self._end_time = end_time

    @property
    def net_funding_summaries(self):
        """
        Gets the net_funding_summaries of this ReportingV3NetFundingsGet200Response.
        List of Netfunding summary objects

        :return: The net_funding_summaries of this ReportingV3NetFundingsGet200Response.
        :rtype: list[ReportingV3NetFundingsGet200ResponseNetFundingSummaries]
        """
        return self._net_funding_summaries

    @net_funding_summaries.setter
    def net_funding_summaries(self, net_funding_summaries):
        """
        Sets the net_funding_summaries of this ReportingV3NetFundingsGet200Response.
        List of Netfunding summary objects

        :param net_funding_summaries: The net_funding_summaries of this ReportingV3NetFundingsGet200Response.
        :type: list[ReportingV3NetFundingsGet200ResponseNetFundingSummaries]
        """

        self._net_funding_summaries = net_funding_summaries

    @property
    def total_purchases(self):
        """
        Gets the total_purchases of this ReportingV3NetFundingsGet200Response.
        List of total purchases currency wise

        :return: The total_purchases of this ReportingV3NetFundingsGet200Response.
        :rtype: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """
        return self._total_purchases

    @total_purchases.setter
    def total_purchases(self, total_purchases):
        """
        Sets the total_purchases of this ReportingV3NetFundingsGet200Response.
        List of total purchases currency wise

        :param total_purchases: The total_purchases of this ReportingV3NetFundingsGet200Response.
        :type: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """

        self._total_purchases = total_purchases

    @property
    def total_refunds(self):
        """
        Gets the total_refunds of this ReportingV3NetFundingsGet200Response.
        List of total refunds currency wise

        :return: The total_refunds of this ReportingV3NetFundingsGet200Response.
        :rtype: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """
        return self._total_refunds

    @total_refunds.setter
    def total_refunds(self, total_refunds):
        """
        Sets the total_refunds of this ReportingV3NetFundingsGet200Response.
        List of total refunds currency wise

        :param total_refunds: The total_refunds of this ReportingV3NetFundingsGet200Response.
        :type: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """

        self._total_refunds = total_refunds

    @property
    def total_fees(self):
        """
        Gets the total_fees of this ReportingV3NetFundingsGet200Response.
        List of total fees currency wise

        :return: The total_fees of this ReportingV3NetFundingsGet200Response.
        :rtype: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """
        return self._total_fees

    @total_fees.setter
    def total_fees(self, total_fees):
        """
        Sets the total_fees of this ReportingV3NetFundingsGet200Response.
        List of total fees currency wise

        :param total_fees: The total_fees of this ReportingV3NetFundingsGet200Response.
        :type: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """

        self._total_fees = total_fees

    @property
    def total_chargebacks(self):
        """
        Gets the total_chargebacks of this ReportingV3NetFundingsGet200Response.
        List of total chargebacks currency wise

        :return: The total_chargebacks of this ReportingV3NetFundingsGet200Response.
        :rtype: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """
        return self._total_chargebacks

    @total_chargebacks.setter
    def total_chargebacks(self, total_chargebacks):
        """
        Sets the total_chargebacks of this ReportingV3NetFundingsGet200Response.
        List of total chargebacks currency wise

        :param total_chargebacks: The total_chargebacks of this ReportingV3NetFundingsGet200Response.
        :type: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """

        self._total_chargebacks = total_chargebacks

    @property
    def net_total(self):
        """
        Gets the net_total of this ReportingV3NetFundingsGet200Response.
        List of new total currency wise

        :return: The net_total of this ReportingV3NetFundingsGet200Response.
        :rtype: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """
        return self._net_total

    @net_total.setter
    def net_total(self, net_total):
        """
        Sets the net_total of this ReportingV3NetFundingsGet200Response.
        List of new total currency wise

        :param net_total: The net_total of this ReportingV3NetFundingsGet200Response.
        :type: list[ReportingV3NetFundingsGet200ResponseTotalPurchases]
        """

        self._net_total = net_total

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3NetFundingsGet200Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class VasV2PaymentsPost201ResponseOrderInformationJurisdiction(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'type': 'str',
        'tax_name': 'str',
        'tax_amount': 'str',
        'taxable': 'str',
        'name': 'str',
        'code': 'str',
        'rate': 'str',
        'region': 'str',
        'country': 'str'
    }

    attribute_map = {
        'type': 'type',
        'tax_name': 'taxName',
        'tax_amount': 'taxAmount',
        'taxable': 'taxable',
        'name': 'name',
        'code': 'code',
        'rate': 'rate',
        'region': 'region',
        'country': 'country'
    }

    def __init__(self, type=None, tax_name=None, tax_amount=None, taxable=None, name=None, code=None, rate=None, region=None, country=None):
        """
        VasV2PaymentsPost201ResponseOrderInformationJurisdiction - a model defined in Swagger
        """

        self._type = None
        self._tax_name = None
        self._tax_amount = None
        self._taxable = None
        self._name = None
        self._code = None
        self._rate = None
        self._region = None
        self._country = None

        if type is not None:
          self.type = type
        if tax_name is not None:
          self.tax_name = tax_name
        if tax_amount is not None:
          self.tax_amount = tax_amount
        if taxable is not None:
          self.taxable = taxable
        if name is not None:
          self.name = name
        if code is not None:
          self.code = code
        if rate is not None:
          self.rate = rate
        if region is not None:
          self.region = region
        if country is not None:
          self.country = country

    @property
    def type(self):
        """
        Gets the type of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Type of tax jurisdiction for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`.  Possible values: - `city` - `county` - `state` - `country` - `special` 

        :return: The type of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Type of tax jurisdiction for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`.  Possible values: - `city` - `county` - `state` - `country` - `special` 

        :param type: The type of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if type is not None and len(type) > 15:
            raise ValueError("Invalid value for `type`, length must be less than or equal to `15`")

        self._type = type

    @property
    def tax_name(self):
        """
        Gets the tax_name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Name of the jurisdiction tax for the item. For example, CA State Tax. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The tax_name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._tax_name

    @tax_name.setter
    def tax_name(self, tax_name):
        """
        Sets the tax_name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Name of the jurisdiction tax for the item. For example, CA State Tax. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param tax_name: The tax_name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if tax_name is not None and len(tax_name) > 15:
            raise ValueError("Invalid value for `tax_name`, length must be less than or equal to `15`")

        self._tax_name = tax_name

    @property
    def tax_amount(self):
        """
        Gets the tax_amount of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction tax amount for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The tax_amount of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """
        Sets the tax_amount of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction tax amount for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param tax_amount: The tax_amount of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if tax_amount is not None and len(tax_amount) > 15:
            raise ValueError("Invalid value for `tax_amount`, length must be less than or equal to `15`")

        self._tax_amount = tax_amount

    @property
    def taxable(self):
        """
        Gets the taxable of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction taxable amount for the item, not including product level exemptions. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The taxable of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._taxable

    @taxable.setter
    def taxable(self, taxable):
        """
        Sets the taxable of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction taxable amount for the item, not including product level exemptions. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param taxable: The taxable of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if taxable is not None and len(taxable) > 15:
            raise ValueError("Invalid value for `taxable`, length must be less than or equal to `15`")

        self._taxable = taxable

    @property
    def name(self):
        """
        Gets the name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Free-text description of the jurisdiction for the item. For example, San Mateo County. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Free-text description of the jurisdiction for the item. For example, San Mateo County. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param name: The name of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """

        self._name = name

    @property
    def code(self):
        """
        Gets the code of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction code assigned by the tax provider. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The code of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction code assigned by the tax provider. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param code: The code of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if code is not None and len(code) > 15:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `15`")

        self._code = code

    @property
    def rate(self):
        """
        Gets the rate of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction tax rate for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The rate of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._rate

    @rate.setter
    def rate(self, rate):
        """
        Sets the rate of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Jurisdiction tax rate for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param rate: The rate of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if rate is not None and len(rate) > 15:
            raise ValueError("Invalid value for `rate`, length must be less than or equal to `15`")

        self._rate = rate

    @property
    def region(self):
        """
        Gets the region of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Free-text description of the jurisdiction region for the item. For example, CA (California State) or GB (Great Britain). Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The region of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Free-text description of the jurisdiction region for the item. For example, CA (California State) or GB (Great Britain). Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param region: The region of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if region is not None and len(region) > 15:
            raise ValueError("Invalid value for `region`, length must be less than or equal to `15`")

        self._region = region

    @property
    def country(self):
        """
        Gets the country of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Tax jurisdiction country for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :return: The country of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        Tax jurisdiction country for the item. Returned only if the `taxInformation.showTaxPerLineItem` field is set to `Yes`. 

        :param country: The country of this VasV2PaymentsPost201ResponseOrderInformationJurisdiction.
        :type: str
        """
        if country is not None and len(country) > 15:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `15`")

        self._country = country

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, VasV2PaymentsPost201ResponseOrderInformationJurisdiction):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsMerchantDefinedInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'key': 'str',
        'value': 'str'
    }

    attribute_map = {
        'key': 'key',
        'value': 'value'
    }

    def __init__(self, key=None, value=None):
        """
        Ptsv2paymentsMerchantDefinedInformation - a model defined in Swagger
        """

        self._key = None
        self._value = None

        if key is not None:
          self.key = key
        if value is not None:
          self.value = value

    @property
    def key(self):
        """
        Gets the key of this Ptsv2paymentsMerchantDefinedInformation.
        The number you assign for as the key for your merchant-defined data field. Valid values are 0 to 100.  For example, to set or access the key for the 2nd merchant-defined data field in the array, you would reference `merchantDefinedInformation[1].key`.  #### CyberSource through VisaNet For installment payments with Mastercard in Brazil, use `merchantDefinedInformation[0].key` and `merchantDefinedInformation[1].key` for data that you want to provide to the issuer to identify the transaction.  For details, see the `merchant_defined_data1` request-level field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The key of this Ptsv2paymentsMerchantDefinedInformation.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Ptsv2paymentsMerchantDefinedInformation.
        The number you assign for as the key for your merchant-defined data field. Valid values are 0 to 100.  For example, to set or access the key for the 2nd merchant-defined data field in the array, you would reference `merchantDefinedInformation[1].key`.  #### CyberSource through VisaNet For installment payments with Mastercard in Brazil, use `merchantDefinedInformation[0].key` and `merchantDefinedInformation[1].key` for data that you want to provide to the issuer to identify the transaction.  For details, see the `merchant_defined_data1` request-level field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param key: The key of this Ptsv2paymentsMerchantDefinedInformation.
        :type: str
        """
        if key is not None and len(key) > 50:
            raise ValueError("Invalid value for `key`, length must be less than or equal to `50`")

        self._key = key

    @property
    def value(self):
        """
        Gets the value of this Ptsv2paymentsMerchantDefinedInformation.
        The value you assign for your merchant-defined data field.  For details, see `merchant_defined_data1` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  **Warning** Merchant-defined data fields are not intended to and must not be used to capture personally identifying information. Accordingly, merchants are prohibited from capturing, obtaining, and/or transmitting any personally identifying information in or via the merchant-defined data fields. Personally identifying information includes, but is not limited to, address, credit card number, social security number, driver's license number, state-issued identification number, passport number, and card verification numbers (CVV, CVC2, CVV2, CID, CVN). In the event CyberSource discovers that a merchant is capturing and/or transmitting personally identifying information via the merchant-defined data fields, whether or not intentionally, CyberSource will immediately suspend the merchant's account, which will result in a rejection of any and all transaction requests submitted by the merchant after the point of suspension.  #### CyberSource through VisaNet For installment payments with Mastercard in Brazil, use `merchantDefinedInformation[0].value` and `merchantDefinedInformation[1].value` for data that you want to provide to the issuer to identify the transaction. For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For installment payments with Mastercard in Brazil: - The value for merchantDefinedInformation[0].value corresponds to the following data in the TC 33 capture file5:   - Record: CP07 TCR5   - Position: 25-44   - Field: Reference Field 2 - The value for merchantDefinedInformation[1].value corresponds to the following data in the TC 33 capture file5:   - Record: CP07 TCR5   - Position: 45-64   - Field: Reference Field 3 

        :return: The value of this Ptsv2paymentsMerchantDefinedInformation.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this Ptsv2paymentsMerchantDefinedInformation.
        The value you assign for your merchant-defined data field.  For details, see `merchant_defined_data1` field description in the [Credit Card Services Using the SCMP API Guide.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  **Warning** Merchant-defined data fields are not intended to and must not be used to capture personally identifying information. Accordingly, merchants are prohibited from capturing, obtaining, and/or transmitting any personally identifying information in or via the merchant-defined data fields. Personally identifying information includes, but is not limited to, address, credit card number, social security number, driver's license number, state-issued identification number, passport number, and card verification numbers (CVV, CVC2, CVV2, CID, CVN). In the event CyberSource discovers that a merchant is capturing and/or transmitting personally identifying information via the merchant-defined data fields, whether or not intentionally, CyberSource will immediately suspend the merchant's account, which will result in a rejection of any and all transaction requests submitted by the merchant after the point of suspension.  #### CyberSource through VisaNet For installment payments with Mastercard in Brazil, use `merchantDefinedInformation[0].value` and `merchantDefinedInformation[1].value` for data that you want to provide to the issuer to identify the transaction. For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For details, see \"Installment Payments on CyberSource through VisaNet\" in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For installment payments with Mastercard in Brazil: - The value for merchantDefinedInformation[0].value corresponds to the following data in the TC 33 capture file5:   - Record: CP07 TCR5   - Position: 25-44   - Field: Reference Field 2 - The value for merchantDefinedInformation[1].value corresponds to the following data in the TC 33 capture file5:   - Record: CP07 TCR5   - Position: 45-64   - Field: Reference Field 3 

        :param value: The value of this Ptsv2paymentsMerchantDefinedInformation.
        :type: str
        """
        if value is not None and len(value) > 255:
            raise ValueError("Invalid value for `value`, length must be less than or equal to `255`")

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsMerchantDefinedInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponseRiskInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'profile': 'TssV2TransactionsGet200ResponseRiskInformationProfile',
        'rules': 'list[TssV2TransactionsGet200ResponseRiskInformationRules]',
        'passive_profile': 'TssV2TransactionsGet200ResponseRiskInformationProfile',
        'passive_rules': 'list[TssV2TransactionsGet200ResponseRiskInformationRules]',
        'score': 'TssV2TransactionsGet200ResponseRiskInformationScore',
        'local_time': 'str'
    }

    attribute_map = {
        'profile': 'profile',
        'rules': 'rules',
        'passive_profile': 'passiveProfile',
        'passive_rules': 'passiveRules',
        'score': 'score',
        'local_time': 'localTime'
    }

    def __init__(self, profile=None, rules=None, passive_profile=None, passive_rules=None, score=None, local_time=None):
        """
        TssV2TransactionsGet200ResponseRiskInformation - a model defined in Swagger
        """

        self._profile = None
        self._rules = None
        self._passive_profile = None
        self._passive_rules = None
        self._score = None
        self._local_time = None

        if profile is not None:
          self.profile = profile
        if rules is not None:
          self.rules = rules
        if passive_profile is not None:
          self.passive_profile = passive_profile
        if passive_rules is not None:
          self.passive_rules = passive_rules
        if score is not None:
          self.score = score
        if local_time is not None:
          self.local_time = local_time

    @property
    def profile(self):
        """
        Gets the profile of this TssV2TransactionsGet200ResponseRiskInformation.

        :return: The profile of this TssV2TransactionsGet200ResponseRiskInformation.
        :rtype: TssV2TransactionsGet200ResponseRiskInformationProfile
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """
        Sets the profile of this TssV2TransactionsGet200ResponseRiskInformation.

        :param profile: The profile of this TssV2TransactionsGet200ResponseRiskInformation.
        :type: TssV2TransactionsGet200ResponseRiskInformationProfile
        """

        self._profile = profile

    @property
    def rules(self):
        """
        Gets the rules of this TssV2TransactionsGet200ResponseRiskInformation.

        :return: The rules of this TssV2TransactionsGet200ResponseRiskInformation.
        :rtype: list[TssV2TransactionsGet200ResponseRiskInformationRules]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this TssV2TransactionsGet200ResponseRiskInformation.

        :param rules: The rules of this TssV2TransactionsGet200ResponseRiskInformation.
        :type: list[TssV2TransactionsGet200ResponseRiskInformationRules]
        """

        self._rules = rules

    @property
    def passive_profile(self):
        """
        Gets the passive_profile of this TssV2TransactionsGet200ResponseRiskInformation.

        :return: The passive_profile of this TssV2TransactionsGet200ResponseRiskInformation.
        :rtype: TssV2TransactionsGet200ResponseRiskInformationProfile
        """
        return self._passive_profile

    @passive_profile.setter
    def passive_profile(self, passive_profile):
        """
        Sets the passive_profile of this TssV2TransactionsGet200ResponseRiskInformation.

        :param passive_profile: The passive_profile of this TssV2TransactionsGet200ResponseRiskInformation.
        :type: TssV2TransactionsGet200ResponseRiskInformationProfile
        """

        self._passive_profile = passive_profile

    @property
    def passive_rules(self):
        """
        Gets the passive_rules of this TssV2TransactionsGet200ResponseRiskInformation.

        :return: The passive_rules of this TssV2TransactionsGet200ResponseRiskInformation.
        :rtype: list[TssV2TransactionsGet200ResponseRiskInformationRules]
        """
        return self._passive_rules

    @passive_rules.setter
    def passive_rules(self, passive_rules):
        """
        Sets the passive_rules of this TssV2TransactionsGet200ResponseRiskInformation.

        :param passive_rules: The passive_rules of this TssV2TransactionsGet200ResponseRiskInformation.
        :type: list[TssV2TransactionsGet200ResponseRiskInformationRules]
        """

        self._passive_rules = passive_rules

    @property
    def score(self):
        """
        Gets the score of this TssV2TransactionsGet200ResponseRiskInformation.

        :return: The score of this TssV2TransactionsGet200ResponseRiskInformation.
        :rtype: TssV2TransactionsGet200ResponseRiskInformationScore
        """
        return self._score

    @score.setter
    def score(self, score):
        """
        Sets the score of this TssV2TransactionsGet200ResponseRiskInformation.

        :param score: The score of this TssV2TransactionsGet200ResponseRiskInformation.
        :type: TssV2TransactionsGet200ResponseRiskInformationScore
        """

        self._score = score

    @property
    def local_time(self):
        """
        Gets the local_time of this TssV2TransactionsGet200ResponseRiskInformation.
        Time that the transaction was submitted in local time.

        :return: The local_time of this TssV2TransactionsGet200ResponseRiskInformation.
        :rtype: str
        """
        return self._local_time

    @local_time.setter
    def local_time(self, local_time):
        """
        Sets the local_time of this TssV2TransactionsGet200ResponseRiskInformation.
        Time that the transaction was submitted in local time.

        :param local_time: The local_time of this TssV2TransactionsGet200ResponseRiskInformation.
        :type: str
        """

        self._local_time = local_time

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponseRiskInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsRefundPost201ResponseProcessorInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'transaction_id': 'str',
        'forwarded_acquirer_code': 'str',
        'merchant_number': 'str',
        'response_code': 'str',
        'ach_verification': 'PtsV2PaymentsPost201ResponseProcessorInformationAchVerification'
    }

    attribute_map = {
        'transaction_id': 'transactionId',
        'forwarded_acquirer_code': 'forwardedAcquirerCode',
        'merchant_number': 'merchantNumber',
        'response_code': 'responseCode',
        'ach_verification': 'achVerification'
    }

    def __init__(self, transaction_id=None, forwarded_acquirer_code=None, merchant_number=None, response_code=None, ach_verification=None):
        """
        PtsV2PaymentsRefundPost201ResponseProcessorInformation - a model defined in Swagger
        """

        self._transaction_id = None
        self._forwarded_acquirer_code = None
        self._merchant_number = None
        self._response_code = None
        self._ach_verification = None

        if transaction_id is not None:
          self.transaction_id = transaction_id
        if forwarded_acquirer_code is not None:
          self.forwarded_acquirer_code = forwarded_acquirer_code
        if merchant_number is not None:
          self.merchant_number = merchant_number
        if response_code is not None:
          self.response_code = response_code
        if ach_verification is not None:
          self.ach_verification = ach_verification

    @property
    def transaction_id(self):
        """
        Gets the transaction_id of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        Processor transaction ID.  This value identifies the transaction on a host system. This value is supported only for Moneris. It contains this information:   - Terminal used to process the transaction  - Shift during which the transaction took place  - Batch number  - Transaction number within the batch  You must store this value. If you give the customer a receipt, display this value on the receipt.  Example For the value 66012345001069003:   - Terminal ID = 66012345  - Shift number = 001  - Batch number = 069  - Transaction number = 003 

        :return: The transaction_id of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """
        Sets the transaction_id of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        Processor transaction ID.  This value identifies the transaction on a host system. This value is supported only for Moneris. It contains this information:   - Terminal used to process the transaction  - Shift during which the transaction took place  - Batch number  - Transaction number within the batch  You must store this value. If you give the customer a receipt, display this value on the receipt.  Example For the value 66012345001069003:   - Terminal ID = 66012345  - Shift number = 001  - Batch number = 069  - Transaction number = 003 

        :param transaction_id: The transaction_id of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :type: str
        """
        if transaction_id is not None and len(transaction_id) > 18:
            raise ValueError("Invalid value for `transaction_id`, length must be less than or equal to `18`")

        self._transaction_id = transaction_id

    @property
    def forwarded_acquirer_code(self):
        """
        Gets the forwarded_acquirer_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        Name of the Japanese acquirer that processed the transaction. Returned only for JCN Gateway. Please contact the CyberSource Japan Support Group for more information. 

        :return: The forwarded_acquirer_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._forwarded_acquirer_code

    @forwarded_acquirer_code.setter
    def forwarded_acquirer_code(self, forwarded_acquirer_code):
        """
        Sets the forwarded_acquirer_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        Name of the Japanese acquirer that processed the transaction. Returned only for JCN Gateway. Please contact the CyberSource Japan Support Group for more information. 

        :param forwarded_acquirer_code: The forwarded_acquirer_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :type: str
        """
        if forwarded_acquirer_code is not None and len(forwarded_acquirer_code) > 32:
            raise ValueError("Invalid value for `forwarded_acquirer_code`, length must be less than or equal to `32`")

        self._forwarded_acquirer_code = forwarded_acquirer_code

    @property
    def merchant_number(self):
        """
        Gets the merchant_number of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        Identifier that was assigned to you by your acquirer. This value must be printed on the receipt.  #### Returned by Authorizations and Credits.  This reply field is only supported by merchants who have installed client software on their POS terminals and use these processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX 

        :return: The merchant_number of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._merchant_number

    @merchant_number.setter
    def merchant_number(self, merchant_number):
        """
        Sets the merchant_number of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        Identifier that was assigned to you by your acquirer. This value must be printed on the receipt.  #### Returned by Authorizations and Credits.  This reply field is only supported by merchants who have installed client software on their POS terminals and use these processors: - American Express Direct - Credit Mutuel-CIC - FDC Nashville Global - OmniPay Direct - SIX 

        :param merchant_number: The merchant_number of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :type: str
        """
        if merchant_number is not None and len(merchant_number) > 15:
            raise ValueError("Invalid value for `merchant_number`, length must be less than or equal to `15`")

        self._merchant_number = merchant_number

    @property
    def response_code(self):
        """
        Gets the response_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value.  **Important** Do not use this field to evaluate the result of the authorization.  #### PIN debit Response value that is returned by the processor or bank. **Important** Do not use this field to evaluate the results of the transaction request.  Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.  #### AIBMS If this value is `08`, you can accept the transaction if the customer provides you with identification.  #### Atos This value is the response code sent from Atos and it might also include the response code from the bank. Format: `aa,bb` with the two values separated by a comma and where: - `aa` is the two-digit error message from Atos. - `bb` is the optional two-digit error message from the bank.  #### Comercio Latino This value is the status code and the error or response code received from the processor separated by a colon. Format: [status code]:E[error code] or [status code]:R[response code] Example `2:R06`  #### JCN Gateway Processor-defined detail error code. The associated response category code is in the `processorInformation.responseCategoryCode` field. String (3) 

        :return: The response_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :rtype: str
        """
        return self._response_code

    @response_code.setter
    def response_code(self, response_code):
        """
        Sets the response_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        For most processors, this is the error message sent directly from the bank. Returned only when the processor returns this value.  **Important** Do not use this field to evaluate the result of the authorization.  #### PIN debit Response value that is returned by the processor or bank. **Important** Do not use this field to evaluate the results of the transaction request.  Returned by PIN debit credit, PIN debit purchase, and PIN debit reversal.  #### AIBMS If this value is `08`, you can accept the transaction if the customer provides you with identification.  #### Atos This value is the response code sent from Atos and it might also include the response code from the bank. Format: `aa,bb` with the two values separated by a comma and where: - `aa` is the two-digit error message from Atos. - `bb` is the optional two-digit error message from the bank.  #### Comercio Latino This value is the status code and the error or response code received from the processor separated by a colon. Format: [status code]:E[error code] or [status code]:R[response code] Example `2:R06`  #### JCN Gateway Processor-defined detail error code. The associated response category code is in the `processorInformation.responseCategoryCode` field. String (3) 

        :param response_code: The response_code of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :type: str
        """
        if response_code is not None and len(response_code) > 10:
            raise ValueError("Invalid value for `response_code`, length must be less than or equal to `10`")

        self._response_code = response_code

    @property
    def ach_verification(self):
        """
        Gets the ach_verification of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.

        :return: The ach_verification of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :rtype: PtsV2PaymentsPost201ResponseProcessorInformationAchVerification
        """
        return self._ach_verification

    @ach_verification.setter
    def ach_verification(self, ach_verification):
        """
        Sets the ach_verification of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.

        :param ach_verification: The ach_verification of this PtsV2PaymentsRefundPost201ResponseProcessorInformation.
        :type: PtsV2PaymentsPost201ResponseProcessorInformationAchVerification
        """

        self._ach_verification = ach_verification

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsRefundPost201ResponseProcessorInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsProcessingInformationCaptureOptions(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capture_sequence_number': 'int',
        'total_capture_count': 'int',
        'date_to_capture': 'str'
    }

    attribute_map = {
        'capture_sequence_number': 'captureSequenceNumber',
        'total_capture_count': 'totalCaptureCount',
        'date_to_capture': 'dateToCapture'
    }

    def __init__(self, capture_sequence_number=None, total_capture_count=None, date_to_capture=None):
        """
        Ptsv2paymentsProcessingInformationCaptureOptions - a model defined in Swagger
        """

        self._capture_sequence_number = None
        self._total_capture_count = None
        self._date_to_capture = None

        if capture_sequence_number is not None:
          self.capture_sequence_number = capture_sequence_number
        if total_capture_count is not None:
          self.total_capture_count = total_capture_count
        if date_to_capture is not None:
          self.date_to_capture = date_to_capture

    @property
    def capture_sequence_number(self):
        """
        Gets the capture_sequence_number of this Ptsv2paymentsProcessingInformationCaptureOptions.
        Capture number when requesting multiple partial captures for one authorization. Used along with `totalCaptureCount` to track which capture is being processed.  For example, the second of five captures would be passed to CyberSource as:   - `captureSequenceNumber_ = 2`, and   - `totalCaptureCount = 5` 

        :return: The capture_sequence_number of this Ptsv2paymentsProcessingInformationCaptureOptions.
        :rtype: int
        """
        return self._capture_sequence_number

    @capture_sequence_number.setter
    def capture_sequence_number(self, capture_sequence_number):
        """
        Sets the capture_sequence_number of this Ptsv2paymentsProcessingInformationCaptureOptions.
        Capture number when requesting multiple partial captures for one authorization. Used along with `totalCaptureCount` to track which capture is being processed.  For example, the second of five captures would be passed to CyberSource as:   - `captureSequenceNumber_ = 2`, and   - `totalCaptureCount = 5` 

        :param capture_sequence_number: The capture_sequence_number of this Ptsv2paymentsProcessingInformationCaptureOptions.
        :type: int
        """
        if capture_sequence_number is not None and capture_sequence_number > 99:
            raise ValueError("Invalid value for `capture_sequence_number`, must be a value less than or equal to `99`")
        if capture_sequence_number is not None and capture_sequence_number < 1:
            raise ValueError("Invalid value for `capture_sequence_number`, must be a value greater than or equal to `1`")

        self._capture_sequence_number = capture_sequence_number

    @property
    def total_capture_count(self):
        """
        Gets the total_capture_count of this Ptsv2paymentsProcessingInformationCaptureOptions.
        Total number of captures when requesting multiple partial captures for one payment. Used along with `captureSequenceNumber` field to track which capture is being processed.  For example, the second of five captures would be passed to CyberSource as:   - `captureSequenceNumber = 2`, and   - `totalCaptureCount = 5` 

        :return: The total_capture_count of this Ptsv2paymentsProcessingInformationCaptureOptions.
        :rtype: int
        """
        return self._total_capture_count

    @total_capture_count.setter
    def total_capture_count(self, total_capture_count):
        """
        Sets the total_capture_count of this Ptsv2paymentsProcessingInformationCaptureOptions.
        Total number of captures when requesting multiple partial captures for one payment. Used along with `captureSequenceNumber` field to track which capture is being processed.  For example, the second of five captures would be passed to CyberSource as:   - `captureSequenceNumber = 2`, and   - `totalCaptureCount = 5` 

        :param total_capture_count: The total_capture_count of this Ptsv2paymentsProcessingInformationCaptureOptions.
        :type: int
        """
        if total_capture_count is not None and total_capture_count > 99:
            raise ValueError("Invalid value for `total_capture_count`, must be a value less than or equal to `99`")
        if total_capture_count is not None and total_capture_count < 1:
            raise ValueError("Invalid value for `total_capture_count`, must be a value greater than or equal to `1`")

        self._total_capture_count = total_capture_count

    @property
    def date_to_capture(self):
        """
        Gets the date_to_capture of this Ptsv2paymentsProcessingInformationCaptureOptions.
        Date on which you want the capture to occur. This field is supported only for CyberSource through VisaNet. Format: `MMDD`  #### Used by **Authorization** Optional field. 

        :return: The date_to_capture of this Ptsv2paymentsProcessingInformationCaptureOptions.
        :rtype: str
        """
        return self._date_to_capture

    @date_to_capture.setter
    def date_to_capture(self, date_to_capture):
        """
        Sets the date_to_capture of this Ptsv2paymentsProcessingInformationCaptureOptions.
        Date on which you want the capture to occur. This field is supported only for CyberSource through VisaNet. Format: `MMDD`  #### Used by **Authorization** Optional field. 

        :param date_to_capture: The date_to_capture of this Ptsv2paymentsProcessingInformationCaptureOptions.
        :type: str
        """
        if date_to_capture is not None and len(date_to_capture) > 4:
            raise ValueError("Invalid value for `date_to_capture`, length must be less than or equal to `4`")

        self._date_to_capture = date_to_capture

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsProcessingInformationCaptureOptions):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class UmsV1UsersGet200ResponseContactInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'email': 'str',
        'phone_number': 'str',
        'first_name': 'str',
        'last_name': 'str'
    }

    attribute_map = {
        'email': 'email',
        'phone_number': 'phoneNumber',
        'first_name': 'firstName',
        'last_name': 'lastName'
    }

    def __init__(self, email=None, phone_number=None, first_name=None, last_name=None):
        """
        UmsV1UsersGet200ResponseContactInformation - a model defined in Swagger
        """

        self._email = None
        self._phone_number = None
        self._first_name = None
        self._last_name = None

        if email is not None:
          self.email = email
        if phone_number is not None:
          self.phone_number = phone_number
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this UmsV1UsersGet200ResponseContactInformation.

        :return: The email of this UmsV1UsersGet200ResponseContactInformation.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this UmsV1UsersGet200ResponseContactInformation.

        :param email: The email of this UmsV1UsersGet200ResponseContactInformation.
        :type: str
        """

        self._email = email

    @property
    def phone_number(self):
        """
        Gets the phone_number of this UmsV1UsersGet200ResponseContactInformation.

        :return: The phone_number of this UmsV1UsersGet200ResponseContactInformation.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this UmsV1UsersGet200ResponseContactInformation.

        :param phone_number: The phone_number of this UmsV1UsersGet200ResponseContactInformation.
        :type: str
        """

        self._phone_number = phone_number

    @property
    def first_name(self):
        """
        Gets the first_name of this UmsV1UsersGet200ResponseContactInformation.

        :return: The first_name of this UmsV1UsersGet200ResponseContactInformation.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this UmsV1UsersGet200ResponseContactInformation.

        :param first_name: The first_name of this UmsV1UsersGet200ResponseContactInformation.
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this UmsV1UsersGet200ResponseContactInformation.

        :return: The last_name of this UmsV1UsersGet200ResponseContactInformation.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this UmsV1UsersGet200ResponseContactInformation.

        :param last_name: The last_name of this UmsV1UsersGet200ResponseContactInformation.
        :type: str
        """

        self._last_name = last_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, UmsV1UsersGet200ResponseContactInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1exportcomplianceinquiriesOrderInformationBillTo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'address1': 'str',
        'address2': 'str',
        'address3': 'str',
        'address4': 'str',
        'administrative_area': 'str',
        'country': 'str',
        'locality': 'str',
        'postal_code': 'str',
        'company': 'Riskv1exportcomplianceinquiriesOrderInformationBillToCompany',
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str'
    }

    attribute_map = {
        'address1': 'address1',
        'address2': 'address2',
        'address3': 'address3',
        'address4': 'address4',
        'administrative_area': 'administrativeArea',
        'country': 'country',
        'locality': 'locality',
        'postal_code': 'postalCode',
        'company': 'company',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email'
    }

    def __init__(self, address1=None, address2=None, address3=None, address4=None, administrative_area=None, country=None, locality=None, postal_code=None, company=None, first_name=None, last_name=None, email=None):
        """
        Riskv1exportcomplianceinquiriesOrderInformationBillTo - a model defined in Swagger
        """

        self._address1 = None
        self._address2 = None
        self._address3 = None
        self._address4 = None
        self._administrative_area = None
        self._country = None
        self._locality = None
        self._postal_code = None
        self._company = None
        self._first_name = None
        self._last_name = None
        self._email = None

        self.address1 = address1
        if address2 is not None:
          self.address2 = address2
        if address3 is not None:
          self.address3 = address3
        if address4 is not None:
          self.address4 = address4
        if administrative_area is not None:
          self.administrative_area = administrative_area
        self.country = country
        self.locality = locality
        self.postal_code = postal_code
        if company is not None:
          self.company = company
        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        self.email = email

    @property
    def address1(self):
        """
        Gets the address1 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Payment card billing street address as it appears on the credit card issuer’s records.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet **Important** When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, CyberSource through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, CyberSource through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### FDMS Nashville When the street name is numeric, it must be sent in numeric format. For example, if the address is _One First Street_, it must be sent as _1 1st Street_.  Required if keyed; not used if swiped.  String (20)  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### All other processors: Optional. String (60)  #### For Payouts This field may be sent only for FDC Compass.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting. 

        :return: The address1 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._address1

    @address1.setter
    def address1(self, address1):
        """
        Sets the address1 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Payment card billing street address as it appears on the credit card issuer’s records.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet **Important** When you populate orderInformation.billTo.address1 and orderInformation.billTo.address2, CyberSource through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, CyberSource through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### FDMS Nashville When the street name is numeric, it must be sent in numeric format. For example, if the address is _One First Street_, it must be sent as _1 1st Street_.  Required if keyed; not used if swiped.  String (20)  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### All other processors: Optional. String (60)  #### For Payouts This field may be sent only for FDC Compass.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting. 

        :param address1: The address1 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if address1 is None:
            raise ValueError("Invalid value for `address1`, must not be `None`")
        if address1 is not None and len(address1) > 60:
            raise ValueError("Invalid value for `address1`, length must be less than or equal to `60`")

        self._address1 = address1

    @property
    def address2(self):
        """
        Gets the address2 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Used for additional address information. For example: _Attention: Accounts Payable_ Optional field.  For Payouts: This field may be sent only for FDC Compass.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet **Important** When you populate `orderInformation.billTo.address1` and `orderInformation.billTo.address2`, CyberSource through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, CyberSource through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### Chase Paymentech Solutions, FDC Compass, and TSYS Acquiring Solutions This value is used for AVS.  #### FDMS Nashville `orderInformation.billTo.address1` and `orderInformation.billTo.address2` together cannot exceed 20 characters. String (20)  #### All Other Processors String (60) 

        :return: The address2 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._address2

    @address2.setter
    def address2(self, address2):
        """
        Sets the address2 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Used for additional address information. For example: _Attention: Accounts Payable_ Optional field.  For Payouts: This field may be sent only for FDC Compass.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet **Important** When you populate `orderInformation.billTo.address1` and `orderInformation.billTo.address2`, CyberSource through VisaNet concatenates the two values. If the concatenated value exceeds 40 characters, CyberSource through VisaNet truncates the value at 40 characters before sending it to Visa and the issuing bank. Truncating this value affects AVS results and therefore might also affect risk decisions and chargebacks. Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### Chase Paymentech Solutions, FDC Compass, and TSYS Acquiring Solutions This value is used for AVS.  #### FDMS Nashville `orderInformation.billTo.address1` and `orderInformation.billTo.address2` together cannot exceed 20 characters. String (20)  #### All Other Processors String (60) 

        :param address2: The address2 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if address2 is not None and len(address2) > 60:
            raise ValueError("Invalid value for `address2`, length must be less than or equal to `60`")

        self._address2 = address2

    @property
    def address3(self):
        """
        Gets the address3 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Additional address information (third line of the billing address) 

        :return: The address3 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._address3

    @address3.setter
    def address3(self, address3):
        """
        Sets the address3 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Additional address information (third line of the billing address) 

        :param address3: The address3 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if address3 is not None and len(address3) > 60:
            raise ValueError("Invalid value for `address3`, length must be less than or equal to `60`")

        self._address3 = address3

    @property
    def address4(self):
        """
        Gets the address4 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Additional address information (fourth line of the billing address) 

        :return: The address4 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._address4

    @address4.setter
    def address4(self, address4):
        """
        Sets the address4 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Additional address information (fourth line of the billing address) 

        :param address4: The address4 of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if address4 is not None and len(address4) > 60:
            raise ValueError("Invalid value for `address4`, length must be less than or equal to `60`")

        self._address4 = address4

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  For Payouts: This field may be sent only for FDC Compass.  ##### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The administrative_area of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        State or province of the billing address. Use the [State, Province, and Territory Codes for the United States and Canada](https://developer.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  For Payouts: This field may be sent only for FDC Compass.  ##### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param administrative_area: The administrative_area of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if administrative_area is not None and len(administrative_area) > 20:
            raise ValueError("Invalid value for `administrative_area`, length must be less than or equal to `20`")

        self._administrative_area = administrative_area

    @property
    def country(self):
        """
        Gets the country of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Payment card billing country. Use the two-character [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The country of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Payment card billing country. Use the two-character [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param country: The country of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if country is None:
            raise ValueError("Invalid value for `country`, must not be `None`")
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    @property
    def locality(self):
        """
        Gets the locality of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Payment card billing city.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The locality of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Payment card billing city.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param locality: The locality of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if locality is None:
            raise ValueError("Invalid value for `locality`, must not be `None`")
        if locality is not None and len(locality) > 50:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `50`")

        self._locality = locality

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Postal code for the billing address. The postal code must consist of 5 to 9 digits.  When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits]  **Example** `12345-6789`  When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric]  **Example** `A1B 2C3`  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### For Payouts:  This field may be sent only for FDC Compass.  #### American Express Direct Before sending the postal code to the processor, CyberSource removes all nonalphanumeric characters and, if the remaining value is longer than nine characters, truncates the value starting from the right side.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### FDMS Nashville Required if `pointOfSaleInformation.entryMode=keyed` and the address is in the U.S. or Canada. Optional if `pointOfSaleInformation.entryMode=keyed` and the address is **not** in the U.S. or Canada. Not used if swiped.  #### RBS WorldPay Atlanta: For best card-present keyed rates, send the postal code if `pointOfSaleInformation.entryMode=keyed`.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### All other processors: Optional field. 

        :return: The postal_code of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Postal code for the billing address. The postal code must consist of 5 to 9 digits.  When the billing country is the U.S., the 9-digit postal code must follow this format: [5 digits][dash][4 digits]  **Example** `12345-6789`  When the billing country is Canada, the 6-digit postal code must follow this format: [alpha][numeric][alpha][space][numeric][alpha][numeric]  **Example** `A1B 2C3`  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### For Payouts:  This field may be sent only for FDC Compass.  #### American Express Direct Before sending the postal code to the processor, CyberSource removes all nonalphanumeric characters and, if the remaining value is longer than nine characters, truncates the value starting from the right side.  #### Atos This field must not contain colons (:).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### FDMS Nashville Required if `pointOfSaleInformation.entryMode=keyed` and the address is in the U.S. or Canada. Optional if `pointOfSaleInformation.entryMode=keyed` and the address is **not** in the U.S. or Canada. Not used if swiped.  #### RBS WorldPay Atlanta: For best card-present keyed rates, send the postal code if `pointOfSaleInformation.entryMode=keyed`.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### All other processors: Optional field. 

        :param postal_code: The postal_code of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if postal_code is None:
            raise ValueError("Invalid value for `postal_code`, must not be `None`")
        if postal_code is not None and len(postal_code) > 10:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `10`")

        self._postal_code = postal_code

    @property
    def company(self):
        """
        Gets the company of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.

        :return: The company of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: Riskv1exportcomplianceinquiriesOrderInformationBillToCompany
        """
        return self._company

    @company.setter
    def company(self, company):
        """
        Sets the company of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.

        :param company: The company of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: Riskv1exportcomplianceinquiriesOrderInformationBillToCompany
        """

        self._company = company

    @property
    def first_name(self):
        """
        Gets the first_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Customer’s first name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called _CyberSource Latin American Processing_. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The first_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Customer’s first name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called _CyberSource Latin American Processing_. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param first_name: The first_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if first_name is not None and len(first_name) > 60:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `60`")

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Customer’s last name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### OmniPay Direct Optional field.  #### RBS WorldPay Atlanta Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The last_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Customer’s last name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### OmniPay Direct Optional field.  #### RBS WorldPay Atlanta Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param last_name: The last_name of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if last_name is not None and len(last_name) > 60:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `60`")

        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Customer's email address, including the full domain name.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  For processor-specific information, see the `customer_email` request-level field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)  #### Invoicing Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The email of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        Customer's email address, including the full domain name.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  For processor-specific information, see the `customer_email` request-level field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)  #### Invoicing Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param email: The email of this Riskv1exportcomplianceinquiriesOrderInformationBillTo.
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")
        if email is not None and len(email) > 255:
            raise ValueError("Invalid value for `email`, length must be less than or equal to `255`")

        self._email = email

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1exportcomplianceinquiriesOrderInformationBillTo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2payoutsSenderInformationAccount(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'funds_source': 'str',
        'number': 'str'
    }

    attribute_map = {
        'funds_source': 'fundsSource',
        'number': 'number'
    }

    def __init__(self, funds_source=None, number=None):
        """
        Ptsv2payoutsSenderInformationAccount - a model defined in Swagger
        """

        self._funds_source = None
        self._number = None

        if funds_source is not None:
          self.funds_source = funds_source
        if number is not None:
          self.number = number

    @property
    def funds_source(self):
        """
        Gets the funds_source of this Ptsv2payoutsSenderInformationAccount.
        Source of funds. Possible values:    Paymentech, CTV, FDC Compass:  - 01: Credit card  - 02: Debit card  - 03: Prepaid card    Paymentech, CTV -  - 04: Cash  - 05: Debit or deposit account that is not linked to a Visa card. Includes checking accounts, savings        accounts, and proprietary debit or ATM cards.  - 06: Credit account that is not linked to a Visa card. Includes credit cards and proprietary lines        of credit.    FDCCompass -   - 04: Deposit Account  **Funds Disbursement**  This value is most likely 05 to identify that the originator used a deposit account to fund the disbursement.  **Credit Card Bill Payment**  This value must be 02, 03, 04, or 05. 

        :return: The funds_source of this Ptsv2payoutsSenderInformationAccount.
        :rtype: str
        """
        return self._funds_source

    @funds_source.setter
    def funds_source(self, funds_source):
        """
        Sets the funds_source of this Ptsv2payoutsSenderInformationAccount.
        Source of funds. Possible values:    Paymentech, CTV, FDC Compass:  - 01: Credit card  - 02: Debit card  - 03: Prepaid card    Paymentech, CTV -  - 04: Cash  - 05: Debit or deposit account that is not linked to a Visa card. Includes checking accounts, savings        accounts, and proprietary debit or ATM cards.  - 06: Credit account that is not linked to a Visa card. Includes credit cards and proprietary lines        of credit.    FDCCompass -   - 04: Deposit Account  **Funds Disbursement**  This value is most likely 05 to identify that the originator used a deposit account to fund the disbursement.  **Credit Card Bill Payment**  This value must be 02, 03, 04, or 05. 

        :param funds_source: The funds_source of this Ptsv2payoutsSenderInformationAccount.
        :type: str
        """
        if funds_source is not None and len(funds_source) > 2:
            raise ValueError("Invalid value for `funds_source`, length must be less than or equal to `2`")
        if funds_source is not None and len(funds_source) < 2:
            raise ValueError("Invalid value for `funds_source`, length must be greater than or equal to `2`")

        self._funds_source = funds_source

    @property
    def number(self):
        """
        Gets the number of this Ptsv2payoutsSenderInformationAccount.
        The account number of the entity funding the transaction. It is the sender’s account number. It can be a debit/credit card account number or bank account number.  **Funds disbursements**  This field is optional.  **All other transactions**  This field is required when the sender funds the transaction with a financial instrument, for example debit card. Length: * FDCCompass (<= 19) * Paymentech (<= 16) 

        :return: The number of this Ptsv2payoutsSenderInformationAccount.
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """
        Sets the number of this Ptsv2payoutsSenderInformationAccount.
        The account number of the entity funding the transaction. It is the sender’s account number. It can be a debit/credit card account number or bank account number.  **Funds disbursements**  This field is optional.  **All other transactions**  This field is required when the sender funds the transaction with a financial instrument, for example debit card. Length: * FDCCompass (<= 19) * Paymentech (<= 16) 

        :param number: The number of this Ptsv2payoutsSenderInformationAccount.
        :type: str
        """
        if number is not None and len(number) > 34:
            raise ValueError("Invalid value for `number`, length must be less than or equal to `34`")

        self._number = number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2payoutsSenderInformationAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'bill_payment_program_enabled': 'bool',
        'bank_transfer_options': 'Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformationBankTransferOptions'
    }

    attribute_map = {
        'bill_payment_program_enabled': 'billPaymentProgramEnabled',
        'bank_transfer_options': 'bankTransferOptions'
    }

    def __init__(self, bill_payment_program_enabled=None, bank_transfer_options=None):
        """
        Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation - a model defined in Swagger
        """

        self._bill_payment_program_enabled = None
        self._bank_transfer_options = None

        if bill_payment_program_enabled is not None:
          self.bill_payment_program_enabled = bill_payment_program_enabled
        if bank_transfer_options is not None:
          self.bank_transfer_options = bank_transfer_options

    @property
    def bill_payment_program_enabled(self):
        """
        Gets the bill_payment_program_enabled of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.
        Flag that indicates that this is a payment for a bill or for an existing contractual loan. For processor-specific details, see the `bill_payment` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  Valid values: - `true`: Bill payment or loan payment. - `false` (default): Not a bill payment or loan payment. 

        :return: The bill_payment_program_enabled of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.
        :rtype: bool
        """
        return self._bill_payment_program_enabled

    @bill_payment_program_enabled.setter
    def bill_payment_program_enabled(self, bill_payment_program_enabled):
        """
        Sets the bill_payment_program_enabled of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.
        Flag that indicates that this is a payment for a bill or for an existing contractual loan. For processor-specific details, see the `bill_payment` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  Valid values: - `true`: Bill payment or loan payment. - `false` (default): Not a bill payment or loan payment. 

        :param bill_payment_program_enabled: The bill_payment_program_enabled of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.
        :type: bool
        """

        self._bill_payment_program_enabled = bill_payment_program_enabled

    @property
    def bank_transfer_options(self):
        """
        Gets the bank_transfer_options of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.

        :return: The bank_transfer_options of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.
        :rtype: Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformationBankTransferOptions
        """
        return self._bank_transfer_options

    @bank_transfer_options.setter
    def bank_transfer_options(self, bank_transfer_options):
        """
        Sets the bank_transfer_options of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.

        :param bank_transfer_options: The bank_transfer_options of this Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation.
        :type: Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformationBankTransferOptions
        """

        self._bank_transfer_options = bank_transfer_options

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Tmsv2customersEmbeddedDefaultPaymentInstrumentProcessingInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponsePointOfSaleInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'emv': 'PtsV2PaymentsPost201ResponsePointOfSaleInformationEmv',
        'amex_capn_data': 'str',
        'terminal_id': 'str'
    }

    attribute_map = {
        'emv': 'emv',
        'amex_capn_data': 'amexCapnData',
        'terminal_id': 'terminalId'
    }

    def __init__(self, emv=None, amex_capn_data=None, terminal_id=None):
        """
        PtsV2PaymentsPost201ResponsePointOfSaleInformation - a model defined in Swagger
        """

        self._emv = None
        self._amex_capn_data = None
        self._terminal_id = None

        if emv is not None:
          self.emv = emv
        if amex_capn_data is not None:
          self.amex_capn_data = amex_capn_data
        if terminal_id is not None:
          self.terminal_id = terminal_id

    @property
    def emv(self):
        """
        Gets the emv of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.

        :return: The emv of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        :rtype: PtsV2PaymentsPost201ResponsePointOfSaleInformationEmv
        """
        return self._emv

    @emv.setter
    def emv(self, emv):
        """
        Sets the emv of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.

        :param emv: The emv of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        :type: PtsV2PaymentsPost201ResponsePointOfSaleInformationEmv
        """

        self._emv = emv

    @property
    def amex_capn_data(self):
        """
        Gets the amex_capn_data of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        Point-of-sale details for the transaction. This value is returned only for **American Express Direct**. CyberSource generates this value, which consists of a series of codes that identify terminal capability, security data, and specific conditions present at the time the transaction occurred. To comply with the CAPN requirements, this value must be included in all subsequent follow-on requests, such as captures and follow-on credits.  When you perform authorizations, captures, and credits through CyberSource, CyberSource passes this value from the authorization service to the subsequent services for you. However, when you perform authorizations through CyberSource and perform subsequent services through other financial institutions, you must ensure that your requests for captures and credits include this value.  For details, see `auth_pos_data` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :return: The amex_capn_data of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        :rtype: str
        """
        return self._amex_capn_data

    @amex_capn_data.setter
    def amex_capn_data(self, amex_capn_data):
        """
        Sets the amex_capn_data of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        Point-of-sale details for the transaction. This value is returned only for **American Express Direct**. CyberSource generates this value, which consists of a series of codes that identify terminal capability, security data, and specific conditions present at the time the transaction occurred. To comply with the CAPN requirements, this value must be included in all subsequent follow-on requests, such as captures and follow-on credits.  When you perform authorizations, captures, and credits through CyberSource, CyberSource passes this value from the authorization service to the subsequent services for you. However, when you perform authorizations through CyberSource and perform subsequent services through other financial institutions, you must ensure that your requests for captures and credits include this value.  For details, see `auth_pos_data` field description in [Credit Card Services Using the SCMP API.](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/) 

        :param amex_capn_data: The amex_capn_data of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        :type: str
        """
        if amex_capn_data is not None and len(amex_capn_data) > 15:
            raise ValueError("Invalid value for `amex_capn_data`, length must be less than or equal to `15`")

        self._amex_capn_data = amex_capn_data

    @property
    def terminal_id(self):
        """
        Gets the terminal_id of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.  #### CyberSource through VisaNet A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support.  When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.  #### FDC Nashville Global To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.  #### For Payouts This field is applicable for CyberSource through VisaNet.  #### GPX Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support.  When you do not include this field in a request, the default value that is defined in your account is used.  Optional for authorizations.  #### Used by **Authorization** Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.   - American Express Direct   - Credit Mutuel-CIC   - FDC Nashville Global   - SIX - Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include `pointOfSaleInformation.catLevel`. - FDMS Nashville: The default value that is defined in your account is used. - GPX - OmniPay Direct: Optional field.  For the following processors, this field is not used. - GPN - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions - Worldpay VAP  #### Card Present reply Terminal identifier assigned by the acquirer. This value must be printed on the receipt. 

        :return: The terminal_id of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        :rtype: str
        """
        return self._terminal_id

    @terminal_id.setter
    def terminal_id(self, terminal_id):
        """
        Sets the terminal_id of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        Identifier for the terminal at your retail location. You can define this value yourself, but consult the processor for requirements.  #### CyberSource through VisaNet A list of all possible values is stored in your CyberSource account. If terminal ID validation is enabled for your CyberSource account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact CyberSource Customer Support.  When you do not include this field in a request, CyberSource uses the default value that is defined in your CyberSource account.  #### FDC Nashville Global To have your account configured to support this field, contact CyberSource Customer Support. This value must be a value that FDC Nashville Global issued to you.  #### For Payouts This field is applicable for CyberSource through VisaNet.  #### GPX Identifier for the terminal at your retail location. A list of all possible values is stored in your account. If terminal ID validation is enabled for your account, the value you send for this field is validated against the list each time you include the field in a request. To enable or disable terminal ID validation, contact customer support.  When you do not include this field in a request, the default value that is defined in your account is used.  Optional for authorizations.  #### Used by **Authorization** Optional for the following processors. When you do not include this field in a request, the default value that is defined in your account is used.   - American Express Direct   - Credit Mutuel-CIC   - FDC Nashville Global   - SIX - Chase Paymentech Solutions: Optional field. If you include this field in your request, you must also include `pointOfSaleInformation.catLevel`. - FDMS Nashville: The default value that is defined in your account is used. - GPX - OmniPay Direct: Optional field.  For the following processors, this field is not used. - GPN - JCN Gateway - RBS WorldPay Atlanta - TSYS Acquiring Solutions - Worldpay VAP  #### Card Present reply Terminal identifier assigned by the acquirer. This value must be printed on the receipt. 

        :param terminal_id: The terminal_id of this PtsV2PaymentsPost201ResponsePointOfSaleInformation.
        :type: str
        """
        if terminal_id is not None and len(terminal_id) > 8:
            raise ValueError("Invalid value for `terminal_id`, length must be less than or equal to `8`")

        self._terminal_id = terminal_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponsePointOfSaleInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1liststypeentriesPaymentInformationBank(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_number': 'str',
        'code': 'str',
        'country': 'str',
        'iban': 'str'
    }

    attribute_map = {
        'account_number': 'accountNumber',
        'code': 'code',
        'country': 'country',
        'iban': 'iban'
    }

    def __init__(self, account_number=None, code=None, country=None, iban=None):
        """
        Riskv1liststypeentriesPaymentInformationBank - a model defined in Swagger
        """

        self._account_number = None
        self._code = None
        self._country = None
        self._iban = None

        if account_number is not None:
          self.account_number = account_number
        if code is not None:
          self.code = code
        if country is not None:
          self.country = country
        if iban is not None:
          self.iban = iban

    @property
    def account_number(self):
        """
        Gets the account_number of this Riskv1liststypeentriesPaymentInformationBank.
        Customer's bank account number. You can use this field only when scoring a direct debit transaction. Use this field if you do not or are not allowed to provide the IBAN. Note Do not use the IBAN in this field. Use nly the traditional account number information. For the IBAN, use bank_iban. 

        :return: The account_number of this Riskv1liststypeentriesPaymentInformationBank.
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """
        Sets the account_number of this Riskv1liststypeentriesPaymentInformationBank.
        Customer's bank account number. You can use this field only when scoring a direct debit transaction. Use this field if you do not or are not allowed to provide the IBAN. Note Do not use the IBAN in this field. Use nly the traditional account number information. For the IBAN, use bank_iban. 

        :param account_number: The account_number of this Riskv1liststypeentriesPaymentInformationBank.
        :type: str
        """
        if account_number is not None and len(account_number) > 30:
            raise ValueError("Invalid value for `account_number`, length must be less than or equal to `30`")

        self._account_number = account_number

    @property
    def code(self):
        """
        Gets the code of this Riskv1liststypeentriesPaymentInformationBank.
        Country-specific code used to identify the customer’s bank. Required for some countries if you do not or are not allowed to provide the IBAN instead. You can use this field only when scoring a direct debit transaction. For specific requirements, see \"Required Bank Account Information by Country,\" 

        :return: The code of this Riskv1liststypeentriesPaymentInformationBank.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this Riskv1liststypeentriesPaymentInformationBank.
        Country-specific code used to identify the customer’s bank. Required for some countries if you do not or are not allowed to provide the IBAN instead. You can use this field only when scoring a direct debit transaction. For specific requirements, see \"Required Bank Account Information by Country,\" 

        :param code: The code of this Riskv1liststypeentriesPaymentInformationBank.
        :type: str
        """
        if code is not None and len(code) > 15:
            raise ValueError("Invalid value for `code`, length must be less than or equal to `15`")

        self._code = code

    @property
    def country(self):
        """
        Gets the country of this Riskv1liststypeentriesPaymentInformationBank.
        Country where the bank is located. Use the two-character ISO codes. You can use this field only when scoring a direct debit transaction. 

        :return: The country of this Riskv1liststypeentriesPaymentInformationBank.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Riskv1liststypeentriesPaymentInformationBank.
        Country where the bank is located. Use the two-character ISO codes. You can use this field only when scoring a direct debit transaction. 

        :param country: The country of this Riskv1liststypeentriesPaymentInformationBank.
        :type: str
        """
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    @property
    def iban(self):
        """
        Gets the iban of this Riskv1liststypeentriesPaymentInformationBank.
        International Bank Account Number (IBAN) for the bank account. For some countries you can provide this number instead of the traditional bank account information. You can use this field only when scoring a direct debit transaction. For specific requirements, see \"Required Bank Account Information by Country,\" 

        :return: The iban of this Riskv1liststypeentriesPaymentInformationBank.
        :rtype: str
        """
        return self._iban

    @iban.setter
    def iban(self, iban):
        """
        Sets the iban of this Riskv1liststypeentriesPaymentInformationBank.
        International Bank Account Number (IBAN) for the bank account. For some countries you can provide this number instead of the traditional bank account information. You can use this field only when scoring a direct debit transaction. For specific requirements, see \"Required Bank Account Information by Country,\" 

        :param iban: The iban of this Riskv1liststypeentriesPaymentInformationBank.
        :type: str
        """
        if iban is not None and len(iban) > 30:
            raise ValueError("Invalid value for `iban`, length must be less than or equal to `30`")

        self._iban = iban

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1liststypeentriesPaymentInformationBank):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
